"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jobresponse import JobResponse, JobResponseTypedDict
from .paginationdetails import PaginationDetails, PaginationDetailsTypedDict
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class JobListResponseTypedDict(TypedDict):
    jobs: List[JobResponseTypedDict]
    pagination: PaginationDetailsTypedDict


class JobListResponse(BaseModel):
    jobs: List[JobResponse]

    pagination: PaginationDetails
