"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jwtpayload import JWTPayload, JWTPayloadTypedDict
from .testcaseupdate import TestCaseUpdate, TestCaseUpdateTypedDict
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class BodyUpdateTestCaseTestCasesTestCaseIDPutTypedDict(TypedDict):
    test_case_in: TestCaseUpdateTypedDict
    r"""Schema for updating a test case (all fields optional)"""
    current_user_payload: JWTPayloadTypedDict
    r"""Schema representing the essential parts of a JWT payload for user identification."""


class BodyUpdateTestCaseTestCasesTestCaseIDPut(BaseModel):
    test_case_in: TestCaseUpdate
    r"""Schema for updating a test case (all fields optional)"""

    current_user_payload: JWTPayload
    r"""Schema representing the essential parts of a JWT payload for user identification."""
