"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .testcasevalidationupdate import (
    TestCaseValidationUpdate,
    TestCaseValidationUpdateTypedDict,
)
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from typing import Any
from typing_extensions import Annotated, TypedDict


class UpdateTestCaseValidationValidationsValidationIDPutRequestTypedDict(TypedDict):
    validation_id: str
    current_user_payload: Any
    test_case_validation_update: TestCaseValidationUpdateTypedDict


class UpdateTestCaseValidationValidationsValidationIDPutRequest(BaseModel):
    validation_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    current_user_payload: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    test_case_validation_update: Annotated[
        TestCaseValidationUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
