"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ProjectArchiveResponseTypedDict(TypedDict):
    id: str
    is_active: bool


class ProjectArchiveResponse(BaseModel):
    id: str

    is_active: bool
