"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .testcasevalidationread import (
    TestCaseValidationRead,
    TestCaseValidationReadTypedDict,
)
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PaginatedResponseTestCaseValidationReadTypedDict(TypedDict):
    items: List[TestCaseValidationReadTypedDict]
    total: int
    page: int
    pages: int
    has_more: bool


class PaginatedResponseTestCaseValidationRead(BaseModel):
    items: List[TestCaseValidationRead]

    total: int

    page: int

    pages: int

    has_more: bool
