"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectvalidatorresponse import (
    ProjectValidatorResponse,
    ProjectValidatorResponseTypedDict,
)
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ProjectValidatorListResponseTypedDict(TypedDict):
    r"""Schema for listing project validators."""

    validators: List[ProjectValidatorResponseTypedDict]


class ProjectValidatorListResponse(BaseModel):
    r"""Schema for listing project validators."""

    validators: List[ProjectValidatorResponse]
