"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Any
from typing_extensions import Annotated, TypedDict


class DeleteValidationValidationsValidationIDDeleteRequestTypedDict(TypedDict):
    validation_id: str
    current_user_payload: Any


class DeleteValidationValidationsValidationIDDeleteRequest(BaseModel):
    validation_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    current_user_payload: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
