"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class JWTTokenTypedDict(TypedDict):
    jwt: str


class JWTToken(BaseModel):
    jwt: str
