"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ValidationItemFeedbackTypedDict(TypedDict):
    r"""Schema for reading/returning validation item feedback"""

    trajectory_item_id: str
    feedback_text: str
    id: str
    test_case_validation_id: str
    created_at: datetime
    updated_at: datetime


class ValidationItemFeedback(BaseModel):
    r"""Schema for reading/returning validation item feedback"""

    trajectory_item_id: str

    feedback_text: str

    id: str

    test_case_validation_id: str

    created_at: datetime

    updated_at: datetime
