"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectupdate import ProjectUpdate, ProjectUpdateTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateProjectProjectsProjectIDPatchRequestTypedDict(TypedDict):
    project_id: str
    project_update: ProjectUpdateTypedDict


class UpdateProjectProjectsProjectIDPatchRequest(BaseModel):
    project_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    project_update: Annotated[
        ProjectUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
