"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .testcasecreate import TestCaseCreate, TestCaseCreateTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateTestCaseTestCasesPostRequestTypedDict(TypedDict):
    test_case_create: TestCaseCreateTypedDict
    api_key_user_id: NotRequired[str]


class CreateTestCaseTestCasesPostRequest(BaseModel):
    test_case_create: Annotated[
        TestCaseCreate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    api_key_user_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = "mock_api_key_user_id"
