"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .stageupdatepayload import StageUpdatePayload, StageUpdatePayloadTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateStageStagesStageIDPutRequestTypedDict(TypedDict):
    stage_id: int
    stage_update_payload: StageUpdatePayloadTypedDict


class UpdateStageStagesStageIDPutRequest(BaseModel):
    stage_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    stage_update_payload: Annotated[
        StageUpdatePayload,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
