"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class ValidatorCompleteSignupRequestTypedDict(TypedDict):
    validation_task_id: str
    validator_id: str
    unique_url_key: str


class ValidatorCompleteSignupRequest(BaseModel):
    validation_task_id: Annotated[str, pydantic.Field(alias="validationTaskId")]

    validator_id: Annotated[str, pydantic.Field(alias="validatorId")]

    unique_url_key: Annotated[str, pydantic.Field(alias="uniqueUrlKey")]
