"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, HeaderMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class HandleClerkWebhookEndpointClerkWebhooksPostRequestTypedDict(TypedDict):
    svix_id: NotRequired[str]
    svix_timestamp: NotRequired[str]
    svix_signature: NotRequired[str]


class HandleClerkWebhookEndpointClerkWebhooksPostRequest(BaseModel):
    svix_id: Annotated[
        Optional[str],
        pydantic.Field(alias="svix-id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None

    svix_timestamp: Annotated[
        Optional[str],
        pydantic.Field(alias="svix-timestamp"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None

    svix_signature: Annotated[
        Optional[str],
        pydantic.Field(alias="svix-signature"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
