"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class StageFileTypeEnum(str, Enum):
    AGENT_RULES = "agent_rules"
    TOOL_DEFINITIONS = "tool_definitions"
    DATABASE_SCHEMA_RULES = "database_schema_rules"
    CUSTOM_DATA_FILES = "custom_data_files"
    RELATIONAL_DB_SCHEMA = "relational_db_schema"
