"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .testcasevalidationcreate import (
    TestCaseValidationCreate,
    TestCaseValidationCreateTypedDict,
)
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import Any
from typing_extensions import Annotated, TypedDict


class CreateTestCaseValidationValidationsPostRequestTypedDict(TypedDict):
    current_user_payload: Any
    test_case_validation_create: TestCaseValidationCreateTypedDict


class CreateTestCaseValidationValidationsPostRequest(BaseModel):
    current_user_payload: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    test_case_validation_create: Annotated[
        TestCaseValidationCreate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
