"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .validatorurlinfo import ValidatorURLInfo, ValidatorURLInfoTypedDict
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CreateValidationTaskResponseTypedDict(TypedDict):
    r"""Response schema for creating a validation task for a batch."""

    validation_task_id: str
    batch_id: str
    status: str
    created_at: datetime
    validator_urls: List[ValidatorURLInfoTypedDict]


class CreateValidationTaskResponse(BaseModel):
    r"""Response schema for creating a validation task for a batch."""

    validation_task_id: str

    batch_id: str

    status: str

    created_at: datetime

    validator_urls: List[ValidatorURLInfo]
