"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class DatasetItemReadTypedDict(TypedDict):
    dataset_id: str
    item_data: Dict[str, Any]
    id: str
    created_at: datetime
    updated_at: datetime


class DatasetItemRead(BaseModel):
    dataset_id: str

    item_data: Dict[str, Any]

    id: str

    created_at: datetime

    updated_at: datetime
