"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ValidatorURLInfoTypedDict(TypedDict):
    r"""Information about a validator's access URL for a validation task."""

    validator_id: str
    clerk_user_id: str
    url: str


class ValidatorURLInfo(BaseModel):
    r"""Information about a validator's access URL for a validation task."""

    validator_id: str

    clerk_user_id: str

    url: str
