"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class Role(str, Enum):
    USER = "user"
    VALIDATOR = "validator"


class UserRoleUpdateTypedDict(TypedDict):
    r"""Schema for updating a user's role in Clerk."""

    role: Role


class UserRoleUpdate(BaseModel):
    r"""Schema for updating a user's role in Clerk."""

    role: Role
