"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class PaginationInfoTypedDict(TypedDict):
    total_count: int
    limit: int
    offset: int


class PaginationInfo(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]

    limit: int

    offset: int
