"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "flowai-sdk"
__version__: str = "0.1.6"
__openapi_doc_version__: str = "0.1.0"
__gen_version__: str = "2.610.0"
__user_agent__: str = "speakeasy-sdk/python 0.1.6 2.610.0 0.1.0 flowai-sdk"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass
