"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class JobCreateTypedDict(TypedDict):
    config: Dict[str, Any]


class JobCreate(BaseModel):
    config: Dict[str, Any]
