"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class JobBatchGenerationResponseTypedDict(TypedDict):
    job_id: str
    message: str
    flow_run_id: str
    flow_run_name: str
    flow_run_state: str


class JobBatchGenerationResponse(BaseModel):
    job_id: Annotated[str, pydantic.Field(alias="jobId")]

    message: str

    flow_run_id: str

    flow_run_name: str

    flow_run_state: str
