"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paginationdetails import PaginationDetails, PaginationDetailsTypedDict
from .projectresponse import ProjectResponse, ProjectResponseTypedDict
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ProjectListResponseTypedDict(TypedDict):
    projects: List[ProjectResponseTypedDict]
    pagination: PaginationDetailsTypedDict


class ProjectListResponse(BaseModel):
    projects: List[ProjectResponse]

    pagination: PaginationDetails
