"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectvalidatorcreate import (
    ProjectValidatorCreate,
    ProjectValidatorCreateTypedDict,
)
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class AddProjectValidatorProjectsProjectIDValidatorsPostRequestTypedDict(TypedDict):
    project_id: str
    project_validator_create: ProjectValidatorCreateTypedDict


class AddProjectValidatorProjectsProjectIDValidatorsPostRequest(BaseModel):
    project_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    project_validator_create: Annotated[
        ProjectValidatorCreate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
