"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ValidationTaskReadTypedDict(TypedDict):
    r"""Schema for reading a validation task."""

    batch_id: str
    status: str
    id: str
    created_at: datetime
    updated_at: datetime


class ValidationTaskRead(BaseModel):
    r"""Schema for reading a validation task."""

    batch_id: str

    status: str

    id: str

    created_at: datetime

    updated_at: datetime
