"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jobcreate import JobCreate, JobCreateTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CreateJobForProjectProjectsProjectIDJobsPostRequestTypedDict(TypedDict):
    project_id: str
    job_create: JobCreateTypedDict


class CreateJobForProjectProjectsProjectIDJobsPostRequest(BaseModel):
    project_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    job_create: Annotated[
        JobCreate, FieldMetadata(request=RequestMetadata(media_type="application/json"))
    ]
