"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ValidatorTaskDetailSchemaTypedDict(TypedDict):
    r"""Detailed information about a validator's task for a validation."""

    validator_task_id: str
    validator_id: str
    clerk_user_id: str
    status: str
    url: str


class ValidatorTaskDetailSchema(BaseModel):
    r"""Detailed information about a validator's task for a validation."""

    validator_task_id: str

    validator_id: str

    clerk_user_id: str

    status: str

    url: str
