"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class ToolOutputTypedDict(TypedDict):
    output: Dict[str, Any]
    id: str
    tool_call_id: str
    created_at: datetime
    updated_at: datetime


class ToolOutput(BaseModel):
    output: Dict[str, Any]

    id: str

    tool_call_id: str

    created_at: datetime

    updated_at: datetime
