"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListStagesStagesGetRequestTypedDict(TypedDict):
    skip: NotRequired[int]
    limit: NotRequired[int]


class ListStagesStagesGetRequest(BaseModel):
    skip: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
