"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .userupdate import UserUpdate, UserUpdateTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import Any
from typing_extensions import Annotated, TypedDict


class UpdateUserMeUsersMePatchRequestTypedDict(TypedDict):
    args: Any
    kwargs: Any
    user_update: UserUpdateTypedDict


class UpdateUserMeUsersMePatchRequest(BaseModel):
    args: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    kwargs: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    user_update: Annotated[
        UserUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
