"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .stagedetailsresponse import StageDetailsResponse, StageDetailsResponseTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class TriggerPipelineFromStagesJobsTriggerPipelineFromStagesPostRequestTypedDict(
    TypedDict
):
    project_id: str
    request_body: List[StageDetailsResponseTypedDict]


class TriggerPipelineFromStagesJobsTriggerPipelineFromStagesPostRequest(BaseModel):
    project_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    request_body: Annotated[
        List[StageDetailsResponse],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
