"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .prefectflowruninfo import PrefectFlowRunInfo, PrefectFlowRunInfoTypedDict
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class PrefectWebhookPayloadTypedDict(TypedDict):
    flow_run: PrefectFlowRunInfoTypedDict


class PrefectWebhookPayload(BaseModel):
    flow_run: PrefectFlowRunInfo
