"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .validatortaskdetailschema import (
    ValidatorTaskDetailSchema,
    ValidatorTaskDetailSchemaTypedDict,
)
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class GetValidationTaskForBatchResponseSchemaTypedDict(TypedDict):
    r"""Response schema for getting a validation task for a batch."""

    id: str
    batch_id: str
    status: str
    created_at: datetime
    updated_at: datetime
    validators: List[ValidatorTaskDetailSchemaTypedDict]


class GetValidationTaskForBatchResponseSchema(BaseModel):
    r"""Response schema for getting a validation task for a batch."""

    id: str

    batch_id: str

    status: str

    created_at: datetime

    updated_at: datetime

    validators: List[ValidatorTaskDetailSchema]
