"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class JWTPayloadTypedDict(TypedDict):
    r"""Schema representing the essential parts of a JWT payload for user identification."""

    sub: str


class JWTPayload(BaseModel):
    r"""Schema representing the essential parts of a JWT payload for user identification."""

    sub: str
