"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class MessageStepCreateTypedDict(TypedDict):
    r"""Schema for creating a message step."""

    order: int
    role: str
    content: str
    type: Literal["message"]


class MessageStepCreate(BaseModel):
    r"""Schema for creating a message step."""

    order: int

    role: str

    content: str

    TYPE: Annotated[
        Annotated[
            Optional[Literal["message"]], AfterValidator(validate_const("message"))
        ],
        pydantic.Field(alias="type"),
    ] = "message"
