"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .datasetitemread import DatasetItemRead, DatasetItemReadTypedDict
from .paginationdetails import PaginationDetails, PaginationDetailsTypedDict
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class DatasetItemListResponseTypedDict(TypedDict):
    items: List[DatasetItemReadTypedDict]
    pagination: PaginationDetailsTypedDict


class DatasetItemListResponse(BaseModel):
    items: List[DatasetItemRead]

    pagination: PaginationDetails
