"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .stagedetailsresponse import StageDetailsResponse, StageDetailsResponseTypedDict
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class StageListResponseTypedDict(TypedDict):
    stages: List[StageDetailsResponseTypedDict]
    total: int
    skip: int
    limit: int


class StageListResponse(BaseModel):
    stages: List[StageDetailsResponse]

    total: int

    skip: int

    limit: int
