"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .listapikeyitem import ListAPIKeyItem, ListAPIKeyItemTypedDict
from .paginationinfo import PaginationInfo, PaginationInfoTypedDict
from flowai_sdk.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class ListAPIKeysResponseTypedDict(TypedDict):
    api_keys: List[ListAPIKeyItemTypedDict]
    pagination: PaginationInfoTypedDict


class ListAPIKeysResponse(BaseModel):
    api_keys: Annotated[List[ListAPIKeyItem], pydantic.Field(alias="apiKeys")]

    pagination: PaginationInfo
