"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class EditTestCaseValidationValidatorTasksValidatorTaskIDValidationsValidationIDPutRequestTypedDict(
    TypedDict
):
    validator_task_id: str
    validation_id: str


class EditTestCaseValidationValidatorTasksValidatorTaskIDValidationsValidationIDPutRequest(
    BaseModel
):
    validator_task_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    validation_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
