"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .body_update_test_case_test_cases_test_case_id_put import (
    BodyUpdateTestCaseTestCasesTestCaseIDPut,
    BodyUpdateTestCaseTestCasesTestCaseIDPutTypedDict,
)
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateTestCaseTestCasesTestCaseIDPutRequestTypedDict(TypedDict):
    test_case_id: str
    body_update_test_case_test_cases_test_case_id_put: (
        BodyUpdateTestCaseTestCasesTestCaseIDPutTypedDict
    )


class UpdateTestCaseTestCasesTestCaseIDPutRequest(BaseModel):
    test_case_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    body_update_test_case_test_cases_test_case_id_put: Annotated[
        BodyUpdateTestCaseTestCasesTestCaseIDPut,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
