"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .datasetgenerationrequest import (
    DatasetGenerationRequest,
    DatasetGenerationRequestTypedDict,
)
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class GenerateDatasetForJobJobsJobIDGenerateDatasetPostRequestTypedDict(TypedDict):
    job_id: str
    dataset_generation_request: DatasetGenerationRequestTypedDict


class GenerateDatasetForJobJobsJobIDGenerateDatasetPostRequest(BaseModel):
    job_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    dataset_generation_request: Annotated[
        DatasetGenerationRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
