"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class PaginationDetailsTypedDict(TypedDict):
    total_count: int
    r"""Total number of projects matching the filter."""
    limit: int
    r"""The limit for the number of projects returned per page."""
    offset: int
    r"""The offset for pagination."""


class PaginationDetails(BaseModel):
    total_count: int
    r"""Total number of projects matching the filter."""

    limit: int
    r"""The limit for the number of projects returned per page."""

    offset: int
    r"""The offset for pagination."""
