"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class APIKeyCreateTypedDict(TypedDict):
    key_name: str
    r"""A user-defined name to identify the key"""


class APIKeyCreate(BaseModel):
    key_name: Annotated[str, pydantic.Field(alias="keyName")]
    r"""A user-defined name to identify the key"""
