"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .apikeyupdate import APIKeyUpdate, APIKeyUpdateTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateAPIKeyDetailsAPIKeysKeyIDPutRequestTypedDict(TypedDict):
    key_id: str
    r"""The ID of the API key to update"""
    api_key_update: APIKeyUpdateTypedDict


class UpdateAPIKeyDetailsAPIKeysKeyIDPutRequest(BaseModel):
    key_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the API key to update"""

    api_key_update: Annotated[
        APIKeyUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
