"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jwtpayload import JWTPayload, JWTPayloadTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class DeleteTestCaseTestCasesTestCaseIDDeleteRequestTypedDict(TypedDict):
    test_case_id: str
    jwt_payload: JWTPayloadTypedDict


class DeleteTestCaseTestCasesTestCaseIDDeleteRequest(BaseModel):
    test_case_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    jwt_payload: Annotated[
        JWTPayload,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
