"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ProjectValidatorCreateTypedDict(TypedDict):
    r"""Schema for adding a validator to a project."""

    email: str
    r"""Email address of the user to add as a validator."""


class ProjectValidatorCreate(BaseModel):
    r"""Schema for adding a validator to a project."""

    email: str
    r"""Email address of the user to add as a validator."""
