"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class TestCaseUpdateTypedDict(TypedDict):
    r"""Schema for updating a test case (all fields optional)"""

    __test__ = False  # pyright: ignore[reportGeneralTypeIssues]

    name: NotRequired[Nullable[str]]
    description: NotRequired[Nullable[str]]
    expected_output: NotRequired[Nullable[str]]
    status: NotRequired[Nullable[str]]
    is_active: NotRequired[Nullable[bool]]


class TestCaseUpdate(BaseModel):
    r"""Schema for updating a test case (all fields optional)"""

    __test__ = False

    name: OptionalNullable[str] = UNSET

    description: OptionalNullable[str] = UNSET

    expected_output: OptionalNullable[str] = UNSET

    status: OptionalNullable[str] = UNSET

    is_active: OptionalNullable[bool] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "name",
            "description",
            "expected_output",
            "status",
            "is_active",
        ]
        nullable_fields = [
            "name",
            "description",
            "expected_output",
            "status",
            "is_active",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
