"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetDatasetItemsDatasetsDatasetIDItemsGetRequestTypedDict(TypedDict):
    dataset_id: str
    limit: NotRequired[int]
    r"""Maximum number of dataset items to return."""
    offset: NotRequired[int]
    r"""Number of dataset items to skip for pagination."""


class GetDatasetItemsDatasetsDatasetIDItemsGetRequest(BaseModel):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 10
    r"""Maximum number of dataset items to return."""

    offset: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0
    r"""Number of dataset items to skip for pagination."""
